OpenFusion GIS Retriever
========================
OGRe fetches geotagged data from publicly available APIs based on a provided
keyword, location, period of time, or media type.
Results are returned in GeoJSON format.

Documentation
-------------
https://ogre.readthedocs.org/
